import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { HealthClientResolvedConfig } from "../HealthClient";
/**
 * @internal
 */
export interface HealthHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface HealthHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<HealthClientResolvedConfig, HandlerExecutionContext, HealthHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultHealthHttpAuthSchemeParametersProvider: (config: HealthClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<HealthHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface HealthHttpAuthSchemeProvider extends HttpAuthSchemeProvider<HealthHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultHealthHttpAuthSchemeProvider: HealthHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: HealthHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: HealthHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
