import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { HealthClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../HealthClient";
import { DescribeEntityAggregatesForOrganizationRequest, DescribeEntityAggregatesForOrganizationResponse } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeEntityAggregatesForOrganizationCommand}.
 */
export interface DescribeEntityAggregatesForOrganizationCommandInput extends DescribeEntityAggregatesForOrganizationRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeEntityAggregatesForOrganizationCommand}.
 */
export interface DescribeEntityAggregatesForOrganizationCommandOutput extends DescribeEntityAggregatesForOrganizationResponse, __MetadataBearer {
}
declare const DescribeEntityAggregatesForOrganizationCommand_base: {
    new (input: DescribeEntityAggregatesForOrganizationCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeEntityAggregatesForOrganizationCommandInput, DescribeEntityAggregatesForOrganizationCommandOutput, HealthClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DescribeEntityAggregatesForOrganizationCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeEntityAggregatesForOrganizationCommandInput, DescribeEntityAggregatesForOrganizationCommandOutput, HealthClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of entity aggregates for your Organizations that are affected by each of the specified events.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { HealthClient, DescribeEntityAggregatesForOrganizationCommand } from "@aws-sdk/client-health"; // ES Modules import
 * // const { HealthClient, DescribeEntityAggregatesForOrganizationCommand } = require("@aws-sdk/client-health"); // CommonJS import
 * const client = new HealthClient(config);
 * const input = { // DescribeEntityAggregatesForOrganizationRequest
 *   eventArns: [ // OrganizationEventArnsList // required
 *     "STRING_VALUE",
 *   ],
 *   awsAccountIds: [ // OrganizationAccountIdsList
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new DescribeEntityAggregatesForOrganizationCommand(input);
 * const response = await client.send(command);
 * // { // DescribeEntityAggregatesForOrganizationResponse
 * //   organizationEntityAggregates: [ // OrganizationEntityAggregatesList
 * //     { // OrganizationEntityAggregate
 * //       eventArn: "STRING_VALUE",
 * //       count: Number("int"),
 * //       statuses: { // entityStatuses
 * //         "<keys>": Number("int"),
 * //       },
 * //       accounts: [ // AccountEntityAggregatesList
 * //         { // AccountEntityAggregate
 * //           accountId: "STRING_VALUE",
 * //           count: Number("int"),
 * //           statuses: {
 * //             "<keys>": Number("int"),
 * //           },
 * //         },
 * //       ],
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeEntityAggregatesForOrganizationCommandInput - {@link DescribeEntityAggregatesForOrganizationCommandInput}
 * @returns {@link DescribeEntityAggregatesForOrganizationCommandOutput}
 * @see {@link DescribeEntityAggregatesForOrganizationCommandInput} for command's `input` shape.
 * @see {@link DescribeEntityAggregatesForOrganizationCommandOutput} for command's `response` shape.
 * @see {@link HealthClientResolvedConfig | config} for HealthClient's `config` shape.
 *
 * @throws {@link HealthServiceException}
 * <p>Base exception class for all service exceptions from Health service.</p>
 *
 * @public
 */
export declare class DescribeEntityAggregatesForOrganizationCommand extends DescribeEntityAggregatesForOrganizationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeEntityAggregatesForOrganizationRequest;
            output: DescribeEntityAggregatesForOrganizationResponse;
        };
        sdk: {
            input: DescribeEntityAggregatesForOrganizationCommandInput;
            output: DescribeEntityAggregatesForOrganizationCommandOutput;
        };
    };
}
