import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { HealthServiceException as __BaseException } from "./HealthServiceException";
export declare const EntityStatusCode: {
  readonly IMPAIRED: "IMPAIRED";
  readonly PENDING: "PENDING";
  readonly RESOLVED: "RESOLVED";
  readonly UNIMPAIRED: "UNIMPAIRED";
  readonly UNKNOWN: "UNKNOWN";
};
export type EntityStatusCode =
  (typeof EntityStatusCode)[keyof typeof EntityStatusCode];
export interface AccountEntityAggregate {
  accountId?: string | undefined;
  count?: number | undefined;
  statuses?: Partial<Record<EntityStatusCode, number>> | undefined;
}
export interface AffectedEntity {
  entityArn?: string | undefined;
  eventArn?: string | undefined;
  entityValue?: string | undefined;
  entityUrl?: string | undefined;
  awsAccountId?: string | undefined;
  lastUpdatedTime?: Date | undefined;
  statusCode?: EntityStatusCode | undefined;
  tags?: Record<string, string> | undefined;
  entityMetadata?: Record<string, string> | undefined;
}
export interface DescribeAffectedAccountsForOrganizationRequest {
  eventArn: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export declare const EventScopeCode: {
  readonly ACCOUNT_SPECIFIC: "ACCOUNT_SPECIFIC";
  readonly NONE: "NONE";
  readonly PUBLIC: "PUBLIC";
};
export type EventScopeCode =
  (typeof EventScopeCode)[keyof typeof EventScopeCode];
export interface DescribeAffectedAccountsForOrganizationResponse {
  affectedAccounts?: string[] | undefined;
  eventScopeCode?: EventScopeCode | undefined;
  nextToken?: string | undefined;
}
export declare class InvalidPaginationToken extends __BaseException {
  readonly name: "InvalidPaginationToken";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<InvalidPaginationToken, __BaseException>
  );
}
export interface DateTimeRange {
  from?: Date | undefined;
  to?: Date | undefined;
}
export interface EntityFilter {
  eventArns: string[] | undefined;
  entityArns?: string[] | undefined;
  entityValues?: string[] | undefined;
  lastUpdatedTimes?: DateTimeRange[] | undefined;
  tags?: Record<string, string>[] | undefined;
  statusCodes?: EntityStatusCode[] | undefined;
}
export interface DescribeAffectedEntitiesRequest {
  filter: EntityFilter | undefined;
  locale?: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface DescribeAffectedEntitiesResponse {
  entities?: AffectedEntity[] | undefined;
  nextToken?: string | undefined;
}
export declare class UnsupportedLocale extends __BaseException {
  readonly name: "UnsupportedLocale";
  readonly $fault: "client";
  constructor(opts: __ExceptionOptionType<UnsupportedLocale, __BaseException>);
}
export interface EntityAccountFilter {
  eventArn: string | undefined;
  awsAccountId?: string | undefined;
  statusCodes?: EntityStatusCode[] | undefined;
}
export interface EventAccountFilter {
  eventArn: string | undefined;
  awsAccountId?: string | undefined;
}
export interface DescribeAffectedEntitiesForOrganizationRequest {
  organizationEntityFilters?: EventAccountFilter[] | undefined;
  locale?: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
  organizationEntityAccountFilters?: EntityAccountFilter[] | undefined;
}
export interface OrganizationAffectedEntitiesErrorItem {
  awsAccountId?: string | undefined;
  eventArn?: string | undefined;
  errorName?: string | undefined;
  errorMessage?: string | undefined;
}
export interface DescribeAffectedEntitiesForOrganizationResponse {
  entities?: AffectedEntity[] | undefined;
  failedSet?: OrganizationAffectedEntitiesErrorItem[] | undefined;
  nextToken?: string | undefined;
}
export interface DescribeEntityAggregatesRequest {
  eventArns?: string[] | undefined;
}
export interface EntityAggregate {
  eventArn?: string | undefined;
  count?: number | undefined;
  statuses?: Partial<Record<EntityStatusCode, number>> | undefined;
}
export interface DescribeEntityAggregatesResponse {
  entityAggregates?: EntityAggregate[] | undefined;
}
export interface DescribeEntityAggregatesForOrganizationRequest {
  eventArns: string[] | undefined;
  awsAccountIds?: string[] | undefined;
}
export interface OrganizationEntityAggregate {
  eventArn?: string | undefined;
  count?: number | undefined;
  statuses?: Partial<Record<EntityStatusCode, number>> | undefined;
  accounts?: AccountEntityAggregate[] | undefined;
}
export interface DescribeEntityAggregatesForOrganizationResponse {
  organizationEntityAggregates?: OrganizationEntityAggregate[] | undefined;
}
export declare const EventAggregateField: {
  readonly EventTypeCategory: "eventTypeCategory";
};
export type EventAggregateField =
  (typeof EventAggregateField)[keyof typeof EventAggregateField];
export declare const EventStatusCode: {
  readonly CLOSED: "closed";
  readonly OPEN: "open";
  readonly UPCOMING: "upcoming";
};
export type EventStatusCode =
  (typeof EventStatusCode)[keyof typeof EventStatusCode];
export declare const EventTypeCategory: {
  readonly ACCOUNT_NOTIFICATION: "accountNotification";
  readonly INVESTIGATION: "investigation";
  readonly ISSUE: "issue";
  readonly SCHEDULED_CHANGE: "scheduledChange";
};
export type EventTypeCategory =
  (typeof EventTypeCategory)[keyof typeof EventTypeCategory];
export interface EventFilter {
  eventArns?: string[] | undefined;
  eventTypeCodes?: string[] | undefined;
  services?: string[] | undefined;
  regions?: string[] | undefined;
  availabilityZones?: string[] | undefined;
  startTimes?: DateTimeRange[] | undefined;
  endTimes?: DateTimeRange[] | undefined;
  lastUpdatedTimes?: DateTimeRange[] | undefined;
  entityArns?: string[] | undefined;
  entityValues?: string[] | undefined;
  eventTypeCategories?: EventTypeCategory[] | undefined;
  tags?: Record<string, string>[] | undefined;
  eventStatusCodes?: EventStatusCode[] | undefined;
}
export interface DescribeEventAggregatesRequest {
  filter?: EventFilter | undefined;
  aggregateField: EventAggregateField | undefined;
  maxResults?: number | undefined;
  nextToken?: string | undefined;
}
export interface EventAggregate {
  aggregateValue?: string | undefined;
  count?: number | undefined;
}
export interface DescribeEventAggregatesResponse {
  eventAggregates?: EventAggregate[] | undefined;
  nextToken?: string | undefined;
}
export interface DescribeEventDetailsRequest {
  eventArns: string[] | undefined;
  locale?: string | undefined;
}
export interface EventDetailsErrorItem {
  eventArn?: string | undefined;
  errorName?: string | undefined;
  errorMessage?: string | undefined;
}
export interface Event {
  arn?: string | undefined;
  service?: string | undefined;
  eventTypeCode?: string | undefined;
  eventTypeCategory?: EventTypeCategory | undefined;
  region?: string | undefined;
  availabilityZone?: string | undefined;
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  lastUpdatedTime?: Date | undefined;
  statusCode?: EventStatusCode | undefined;
  eventScopeCode?: EventScopeCode | undefined;
}
export interface EventDescription {
  latestDescription?: string | undefined;
}
export interface EventDetails {
  event?: Event | undefined;
  eventDescription?: EventDescription | undefined;
  eventMetadata?: Record<string, string> | undefined;
}
export interface DescribeEventDetailsResponse {
  successfulSet?: EventDetails[] | undefined;
  failedSet?: EventDetailsErrorItem[] | undefined;
}
export interface DescribeEventDetailsForOrganizationRequest {
  organizationEventDetailFilters: EventAccountFilter[] | undefined;
  locale?: string | undefined;
}
export interface OrganizationEventDetailsErrorItem {
  awsAccountId?: string | undefined;
  eventArn?: string | undefined;
  errorName?: string | undefined;
  errorMessage?: string | undefined;
}
export interface OrganizationEventDetails {
  awsAccountId?: string | undefined;
  event?: Event | undefined;
  eventDescription?: EventDescription | undefined;
  eventMetadata?: Record<string, string> | undefined;
}
export interface DescribeEventDetailsForOrganizationResponse {
  successfulSet?: OrganizationEventDetails[] | undefined;
  failedSet?: OrganizationEventDetailsErrorItem[] | undefined;
}
export interface DescribeEventsRequest {
  filter?: EventFilter | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
  locale?: string | undefined;
}
export interface DescribeEventsResponse {
  events?: Event[] | undefined;
  nextToken?: string | undefined;
}
export interface OrganizationEventFilter {
  eventTypeCodes?: string[] | undefined;
  awsAccountIds?: string[] | undefined;
  services?: string[] | undefined;
  regions?: string[] | undefined;
  startTime?: DateTimeRange | undefined;
  endTime?: DateTimeRange | undefined;
  lastUpdatedTime?: DateTimeRange | undefined;
  entityArns?: string[] | undefined;
  entityValues?: string[] | undefined;
  eventTypeCategories?: EventTypeCategory[] | undefined;
  eventStatusCodes?: EventStatusCode[] | undefined;
}
export interface DescribeEventsForOrganizationRequest {
  filter?: OrganizationEventFilter | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
  locale?: string | undefined;
}
export interface OrganizationEvent {
  arn?: string | undefined;
  service?: string | undefined;
  eventTypeCode?: string | undefined;
  eventTypeCategory?: EventTypeCategory | undefined;
  eventScopeCode?: EventScopeCode | undefined;
  region?: string | undefined;
  startTime?: Date | undefined;
  endTime?: Date | undefined;
  lastUpdatedTime?: Date | undefined;
  statusCode?: EventStatusCode | undefined;
}
export interface DescribeEventsForOrganizationResponse {
  events?: OrganizationEvent[] | undefined;
  nextToken?: string | undefined;
}
export interface EventTypeFilter {
  eventTypeCodes?: string[] | undefined;
  services?: string[] | undefined;
  eventTypeCategories?: EventTypeCategory[] | undefined;
}
export interface DescribeEventTypesRequest {
  filter?: EventTypeFilter | undefined;
  locale?: string | undefined;
  nextToken?: string | undefined;
  maxResults?: number | undefined;
}
export interface EventType {
  service?: string | undefined;
  code?: string | undefined;
  category?: EventTypeCategory | undefined;
}
export interface DescribeEventTypesResponse {
  eventTypes?: EventType[] | undefined;
  nextToken?: string | undefined;
}
export interface DescribeHealthServiceStatusForOrganizationResponse {
  healthServiceAccessStatusForOrganization?: string | undefined;
}
export declare class ConcurrentModificationException extends __BaseException {
  readonly name: "ConcurrentModificationException";
  readonly $fault: "client";
  constructor(
    opts: __ExceptionOptionType<
      ConcurrentModificationException,
      __BaseException
    >
  );
}
